# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import xchainpy2_thornode
from xchainpy2_thornode.api.streaming_swap_api import StreamingSwapApi  # noqa: E501
from xchainpy2_thornode.rest import ApiException


class TestStreamingSwapApi(unittest.TestCase):
    """StreamingSwapApi unit test stubs"""

    def setUp(self):
        self.api = StreamingSwapApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_stream_swap(self):
        """Test case for stream_swap

        """
        pass

    def test_stream_swaps(self):
        """Test case for stream_swaps

        """
        pass


if __name__ == '__main__':
    unittest.main()
