# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import xchainpy2_thornode
from xchainpy2_thornode.models.keysign_info import KeysignInfo  # noqa: E501
from xchainpy2_thornode.rest import ApiException


class TestKeysignInfo(unittest.TestCase):
    """KeysignInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testKeysignInfo(self):
        """Test KeysignInfo"""
        # FIXME: construct object with mandatory attributes with example values
        # model = xchainpy2_thornode.models.keysign_info.KeysignInfo()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
