# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RUNEPoolResponseProviders(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'units': 'str',
        'pending_units': 'str',
        'pending_rune': 'str',
        'value': 'str',
        'pnl': 'str',
        'current_deposit': 'str'
    }

    attribute_map = {
        'units': 'units',
        'pending_units': 'pending_units',
        'pending_rune': 'pending_rune',
        'value': 'value',
        'pnl': 'pnl',
        'current_deposit': 'current_deposit'
    }

    def __init__(self, units=None, pending_units=None, pending_rune=None, value=None, pnl=None, current_deposit=None):  # noqa: E501
        """RUNEPoolResponseProviders - a model defined in Swagger"""  # noqa: E501
        self._units = None
        self._pending_units = None
        self._pending_rune = None
        self._value = None
        self._pnl = None
        self._current_deposit = None
        self.discriminator = None
        self.units = units
        self.pending_units = pending_units
        self.pending_rune = pending_rune
        self.value = value
        self.pnl = pnl
        self.current_deposit = current_deposit

    @property
    def units(self):
        """Gets the units of this RUNEPoolResponseProviders.  # noqa: E501

        the units of RUNEPool owned by providers (including pending)  # noqa: E501

        :return: The units of this RUNEPoolResponseProviders.  # noqa: E501
        :rtype: str
        """
        return self._units

    @units.setter
    def units(self, units):
        """Sets the units of this RUNEPoolResponseProviders.

        the units of RUNEPool owned by providers (including pending)  # noqa: E501

        :param units: The units of this RUNEPoolResponseProviders.  # noqa: E501
        :type: str
        """
        if units is None:
            raise ValueError("Invalid value for `units`, must not be `None`")  # noqa: E501

        self._units = units

    @property
    def pending_units(self):
        """Gets the pending_units of this RUNEPoolResponseProviders.  # noqa: E501

        the units of RUNEPool owned by providers that remain pending  # noqa: E501

        :return: The pending_units of this RUNEPoolResponseProviders.  # noqa: E501
        :rtype: str
        """
        return self._pending_units

    @pending_units.setter
    def pending_units(self, pending_units):
        """Sets the pending_units of this RUNEPoolResponseProviders.

        the units of RUNEPool owned by providers that remain pending  # noqa: E501

        :param pending_units: The pending_units of this RUNEPoolResponseProviders.  # noqa: E501
        :type: str
        """
        if pending_units is None:
            raise ValueError("Invalid value for `pending_units`, must not be `None`")  # noqa: E501

        self._pending_units = pending_units

    @property
    def pending_rune(self):
        """Gets the pending_rune of this RUNEPoolResponseProviders.  # noqa: E501

        the amount of RUNE pending  # noqa: E501

        :return: The pending_rune of this RUNEPoolResponseProviders.  # noqa: E501
        :rtype: str
        """
        return self._pending_rune

    @pending_rune.setter
    def pending_rune(self, pending_rune):
        """Sets the pending_rune of this RUNEPoolResponseProviders.

        the amount of RUNE pending  # noqa: E501

        :param pending_rune: The pending_rune of this RUNEPoolResponseProviders.  # noqa: E501
        :type: str
        """
        if pending_rune is None:
            raise ValueError("Invalid value for `pending_rune`, must not be `None`")  # noqa: E501

        self._pending_rune = pending_rune

    @property
    def value(self):
        """Gets the value of this RUNEPoolResponseProviders.  # noqa: E501

        the value of the provider share of the RUNEPool (includes pending RUNE)  # noqa: E501

        :return: The value of this RUNEPoolResponseProviders.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this RUNEPoolResponseProviders.

        the value of the provider share of the RUNEPool (includes pending RUNE)  # noqa: E501

        :param value: The value of this RUNEPoolResponseProviders.  # noqa: E501
        :type: str
        """
        if value is None:
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    @property
    def pnl(self):
        """Gets the pnl of this RUNEPoolResponseProviders.  # noqa: E501

        the profit and loss of the provider share of the RUNEPool  # noqa: E501

        :return: The pnl of this RUNEPoolResponseProviders.  # noqa: E501
        :rtype: str
        """
        return self._pnl

    @pnl.setter
    def pnl(self, pnl):
        """Sets the pnl of this RUNEPoolResponseProviders.

        the profit and loss of the provider share of the RUNEPool  # noqa: E501

        :param pnl: The pnl of this RUNEPoolResponseProviders.  # noqa: E501
        :type: str
        """
        if pnl is None:
            raise ValueError("Invalid value for `pnl`, must not be `None`")  # noqa: E501

        self._pnl = pnl

    @property
    def current_deposit(self):
        """Gets the current_deposit of this RUNEPoolResponseProviders.  # noqa: E501

        the current RUNE deposited by providers  # noqa: E501

        :return: The current_deposit of this RUNEPoolResponseProviders.  # noqa: E501
        :rtype: str
        """
        return self._current_deposit

    @current_deposit.setter
    def current_deposit(self, current_deposit):
        """Sets the current_deposit of this RUNEPoolResponseProviders.

        the current RUNE deposited by providers  # noqa: E501

        :param current_deposit: The current_deposit of this RUNEPoolResponseProviders.  # noqa: E501
        :type: str
        """
        if current_deposit is None:
            raise ValueError("Invalid value for `current_deposit`, must not be `None`")  # noqa: E501

        self._current_deposit = current_deposit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RUNEPoolResponseProviders, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RUNEPoolResponseProviders):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
