# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BanResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'node_address': 'str',
        'block_height': 'int',
        'signers': 'list[str]'
    }

    attribute_map = {
        'node_address': 'node_address',
        'block_height': 'block_height',
        'signers': 'signers'
    }

    def __init__(self, node_address=None, block_height=None, signers=None):  # noqa: E501
        """BanResponse - a model defined in Swagger"""  # noqa: E501
        self._node_address = None
        self._block_height = None
        self._signers = None
        self.discriminator = None
        if node_address is not None:
            self.node_address = node_address
        if block_height is not None:
            self.block_height = block_height
        if signers is not None:
            self.signers = signers

    @property
    def node_address(self):
        """Gets the node_address of this BanResponse.  # noqa: E501


        :return: The node_address of this BanResponse.  # noqa: E501
        :rtype: str
        """
        return self._node_address

    @node_address.setter
    def node_address(self, node_address):
        """Sets the node_address of this BanResponse.


        :param node_address: The node_address of this BanResponse.  # noqa: E501
        :type: str
        """

        self._node_address = node_address

    @property
    def block_height(self):
        """Gets the block_height of this BanResponse.  # noqa: E501


        :return: The block_height of this BanResponse.  # noqa: E501
        :rtype: int
        """
        return self._block_height

    @block_height.setter
    def block_height(self, block_height):
        """Sets the block_height of this BanResponse.


        :param block_height: The block_height of this BanResponse.  # noqa: E501
        :type: int
        """

        self._block_height = block_height

    @property
    def signers(self):
        """Gets the signers of this BanResponse.  # noqa: E501


        :return: The signers of this BanResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._signers

    @signers.setter
    def signers(self, signers):
        """Sets the signers of this BanResponse.


        :param signers: The signers of this BanResponse.  # noqa: E501
        :type: list[str]
        """

        self._signers = signers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BanResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BanResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
