# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Account(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'address': 'str',
        'pubkey': 'str',
        'sequence': 'int',
        'account_number': 'int'
    }

    attribute_map = {
        'type': 'type',
        'address': 'address',
        'pubkey': 'pubkey',
        'sequence': 'sequence',
        'account_number': 'account_number'
    }

    def __init__(self, type=None, address=None, pubkey=None, sequence=None, account_number=None):  # noqa: E501
        """Account - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._address = None
        self._pubkey = None
        self._sequence = None
        self._account_number = None
        self.discriminator = None
        if type is not None:
            self.type = type
        if address is not None:
            self.address = address
        if pubkey is not None:
            self.pubkey = pubkey
        if sequence is not None:
            self.sequence = sequence
        if account_number is not None:
            self.account_number = account_number

    @property
    def type(self):
        """Gets the type of this Account.  # noqa: E501


        :return: The type of this Account.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Account.


        :param type: The type of this Account.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def address(self):
        """Gets the address of this Account.  # noqa: E501


        :return: The address of this Account.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this Account.


        :param address: The address of this Account.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def pubkey(self):
        """Gets the pubkey of this Account.  # noqa: E501


        :return: The pubkey of this Account.  # noqa: E501
        :rtype: str
        """
        return self._pubkey

    @pubkey.setter
    def pubkey(self, pubkey):
        """Sets the pubkey of this Account.


        :param pubkey: The pubkey of this Account.  # noqa: E501
        :type: str
        """

        self._pubkey = pubkey

    @property
    def sequence(self):
        """Gets the sequence of this Account.  # noqa: E501


        :return: The sequence of this Account.  # noqa: E501
        :rtype: int
        """
        return self._sequence

    @sequence.setter
    def sequence(self, sequence):
        """Sets the sequence of this Account.


        :param sequence: The sequence of this Account.  # noqa: E501
        :type: int
        """

        self._sequence = sequence

    @property
    def account_number(self):
        """Gets the account_number of this Account.  # noqa: E501


        :return: The account_number of this Account.  # noqa: E501
        :rtype: int
        """
        return self._account_number

    @account_number.setter
    def account_number(self, account_number):
        """Sets the account_number of this Account.


        :param account_number: The account_number of this Account.  # noqa: E501
        :type: int
        """

        self._account_number = account_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Account, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Account):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
